@@ -10,6 +10,7 @@ ENABLE_VENV="false"
 USE_DHCP="false"
 USE_VENV="false"
 BUILD_IMAGE="false"
+BAREMETAL_DATA_FILE=${BAREMETAL_DATA_FILE:-'/tmp/baremetal.json'}
 
 # Set defaults for ansible command-line options to drive the different
 # tests.
@@ -41,6 +42,45 @@ NOAUTH_MODE=true
 ENABLE_KEYSTONE=false
 CLOUD_CONFIG=""
 WAIT_FOR_DEPLOY=true
+ZUUL_BRANCH=${ZUUL_BRANCH:-}
+
+# This sets up the MySQL database like it's done for all OpenStack
+# projects for CI testing.
+mysql_setup() {
+    # The root password for the MySQL database; pass it in via
+    # MYSQL_ROOT_PW.
+    local DB_ROOT_PW=${MYSQL_ROOT_PW:-insecure_slave}
+
+    # This user and its password are used by the tests, if you change it,
+    # your tests might fail.
+    local DB_USER=openstack_citest
+    local DB_PW=openstack_citest
+
+    # Make sure MySQL is running
+    sudo service mysql start || sudo service mysqld start || sudo service mariadb start
+
+    sudo -H mysqladmin -u root password $DB_ROOT_PW
+
+    # It's best practice to remove anonymous users from the database.  If
+    # an anonymous user exists, then it matches first for connections and
+    # other connections from that host will not work.
+    sudo -H mysql -u root -p$DB_ROOT_PW -h localhost -e "
+        DELETE FROM mysql.user WHERE User='';
+        FLUSH PRIVILEGES;
+        GRANT ALL PRIVILEGES ON *.*
+            TO '$DB_USER'@'%' identified by '$DB_PW' WITH GRANT OPTION;"
+
+    # Now create our database.
+    mysql -u $DB_USER -p$DB_PW -h 127.0.0.1 -e "
+        SET default_storage_engine=MYISAM;
+        DROP DATABASE IF EXISTS openstack_citest;
+        CREATE DATABASE openstack_citest CHARACTER SET utf8;"
+}
+
+# Setup openstack_citest database if run in OpenStack CI.
+if [ "$ZUUL_BRANCH" != "" ] ; then
+    mysql_setup
+fi
 
 # NOTE(cinerama): We could remove this if we change the CI job to use
 # USE_DHCP, BUILD_IMAGE, etc.
@@ -57,12 +97,11 @@ fi
 
 if [ ${USE_VENV} = "true" ]; then
     export VENV=/opt/stack/bifrost
-    export PATH=${VENV}/bin:${PATH}
     $SCRIPT_HOME/env-setup.sh
     # Note(cinerama): activate is not compatible with "set -u";
     # disable it just for this line.
     set +u
-    source /opt/stack/bifrost/bin/activate
+    source ${VENV}/bin/activate
     set -u
     ANSIBLE=${VENV}/bin/ansible-playbook
     ENABLE_VENV="true"
@@ -93,6 +132,11 @@ elif [ ${ENABLE_KEYSTONE} = "true" ]; then
     CLOUD_CONFIG="-e cloud_name=bifrost"
 fi
 
+logs_on_exit() {
+    $SCRIPT_HOME/collect-test-info.sh
+}
+trap logs_on_exit EXIT
+
 # Change working directory
 cd $BIFROST_HOME/playbooks
 
@@ -116,17 +160,23 @@ ${ANSIBLE} -vvvv \
        -e test_vm_num_nodes=${TEST_VM_NUM_NODES} \
        -e test_vm_memory_size=${VM_MEMORY_SIZE} \
        -e test_vm_domain_type=${VM_DOMAIN_TYPE} \
+       -e baremetal_json_file=${BAREMETAL_DATA_FILE} \
        -e enable_venv=${ENABLE_VENV}
 
 if [ ${USE_DHCP} = "true" ]; then
-    # cut file to limit number of nodes to enroll for testing purposes
-    head -n -2 /tmp/baremetal.csv > /tmp/baremetal.csv.new && mv /tmp/baremetal.csv.new /tmp/baremetal.csv
+    # reduce the number of nodes in JSON file
+    # to limit number of nodes to enroll for testing purposes
+    python $BIFROST_HOME/scripts/split_json.py 3 \
+        ${BAREMETAL_DATA_FILE} \
+        ${BAREMETAL_DATA_FILE}.new \
+        ${BAREMETAL_DATA_FILE}.rest \
+        && mv ${BAREMETAL_DATA_FILE}.new ${BAREMETAL_DATA_FILE}
 fi
 
 set +e
 
 # Set BIFROST_INVENTORY_SOURCE
-export BIFROST_INVENTORY_SOURCE=/tmp/baremetal.csv
+export BIFROST_INVENTORY_SOURCE=${BAREMETAL_DATA_FILE}
 
 # Execute the installation and VM startup test.
 
@@ -148,6 +198,7 @@ ${ANSIBLE} -vvvv \
     -e noauth_mode=${NOAUTH_MODE} \
     -e enable_keystone=${ENABLE_KEYSTONE} \
     -e wait_for_node_deploy=${WAIT_FOR_DEPLOY} \
+    -e not_enrolled_data_file=${BAREMETAL_DATA_FILE}.rest \
     ${CLOUD_CONFIG}
 EXITCODE=$?
 
@@ -157,6 +208,4 @@ if [ $EXITCODE != 0 ]; then
     echo "****************************"
 fi
 
-$SCRIPT_HOME/collect-test-info.sh
-
 exit $EXITCODE
